#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.3.0.0
visibility:           public
id:                   haskell-language-server-2.3.0.0-K8ZmFVSp0dn2SPNWH1bcTy
key:                  haskell-language-server-2.3.0.0-K8ZmFVSp0dn2SPNWH1bcTy
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  a2bfebf7aa66457ec2924978f504520f
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.3.0.0-K8ZmFVSp0dn2SPNWH1bcTy
depends:
    aeson-pretty-0.8.10-JamRq5m80wd4aZe432zy9L
    async-2.2.5-Fdc9pMGzbs41VPeNh53HMF base-4.18.2.1
    base16-bytestring-1.0.2.0-43PuEznvccJEXl6PPOr0Y1
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-6y5MCgwNMbDHpSkA1UHqLT
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    extra-1.7.16-4Kg1qMVacrqF4OK050WHlc filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.3.0.0-3935vir6BTc9L9sTVS8AJW
    githash-0.1.6.3-5nLgZciGfARJyciV5kbAJc
    hie-bios-0.12.0-6ieqa6F3rJSM7KbCG6tdC
    hiedb-0.4.3.0-AGtWSpehXS7CVIOQDZJo1n
    hls-alternate-number-format-plugin-2.3.0.0-7JmP9md30lfHk2zJfbpdhc
    hls-cabal-fmt-plugin-2.3.0.0-AbGTdCUxJtWCK54Bb0zg4t
    hls-cabal-plugin-2.3.0.0-7YWlyqlo6uKFFHnZ8hFjfE
    hls-call-hierarchy-plugin-2.3.0.0-E0L2ByoBBlkEJEjTjEqha
    hls-change-type-signature-plugin-2.3.0.0-9lqFKf2gDhADD2dNf8DV7O
    hls-class-plugin-2.3.0.0-KEatoMzTomAHEUoW6DFRHC
    hls-code-range-plugin-2.3.0.0-Gl5iOKPTHJcEM36MnTGYzF
    hls-eval-plugin-2.3.0.0-Kvq1Bb6J4lZ15aCQ6sSRBC
    hls-explicit-fixity-plugin-2.3.0.0-1xZQWUInnXAGUjGY3xPXI4
    hls-explicit-imports-plugin-2.3.0.0-HNlQjhXVsq9AZgGydjaws2
    hls-explicit-record-fields-plugin-2.3.0.0-G2GZr0TQVLq2zFnLfZ6i0n
    hls-fourmolu-plugin-2.3.0.0-C0BxQK7gckuCxgrrTmB96j
    hls-gadt-plugin-2.3.0.0-BWkyQ4paUUaDT73suJ6clf
    hls-graph-2.3.0.0-EuUH974vVM5LY5p3RL9zUg
    hls-hlint-plugin-2.3.0.0-8uRZS440GUVHatrHPxrOKU
    hls-module-name-plugin-2.3.0.0-ECcAky2O4LML7BGwRSaKQ1
    hls-ormolu-plugin-2.3.0.0-AOyryFAcceJ2qBzA413ozy
    hls-overloaded-record-dot-plugin-2.3.0.0-HVGAaRFNGPnKmxWZ74DrdW
    hls-plugin-api-2.3.0.0-4olhkqlfyGT9kusfBJKxhd
    hls-pragmas-plugin-2.3.0.0-IWk1SiOi0AqLGCeB4P1yq0
    hls-qualify-imported-names-plugin-2.3.0.0-5KyBblGUqESG3vPYzsGNbn
    hls-refactor-plugin-2.3.0.0-Uy3Nh46SkWFyzM7bkEV4I
    hls-rename-plugin-2.3.0.0-F5C9PRYyNhAE4EUcMCruSE
    hls-retrie-plugin-2.3.0.0-Dfoy6v64z5nYRvkS9yzno
    hls-splice-plugin-2.3.0.0-Lmcy4IDtIv3Eh0ag3Iov0r
    hls-stylish-haskell-plugin-2.3.0.0-6URqwajEQTZHv2CgKHnaed
    lsp-2.2.0.0-LmfZEBKj2mTJOChHjiUsY7
    optparse-applicative-0.18.1.0-8rF5XjVl6TuDFBfJrOgvlf
    optparse-simple-0.1.1.4-8CmOC3obBHG8gvjWFbdlHD
    prettyprinter-1.7.1-43b1HQ60eBR4VVLl706bT0 process-1.6.19.0
    safe-exceptions-0.1.7.4-AiCjJXlnRU369VFHT4MQMI
    sqlite-simple-0.4.19.0-IxRQmtkBb8nDjjYq5buiKk text-2.0.2
    unordered-containers-0.2.20.1-HZplTUppwNB9GgXlMkO7HL

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

